summaryrefslogtreecommitdiff
path: root/svtools
diff options
context:
space:
mode:
authorMichael T. Whiteley <mike@whiteley.org>2011-12-07 02:33:51 -0800
committerTor Lillqvist <tlillqvist@suse.com>2011-12-08 11:32:41 +0200
commitdcfd4beb213c551f6ef6ba379651bf303bd9017a (patch)
treea819f50716357c2a5561f6b9a09809cfc52d7dbf /svtools
parentad2eb6c4ba3ca36e2302c721a106dac80d266325 (diff)
childs -> children
Diffstat (limited to 'svtools')
-rw-r--r--svtools/inc/svtools/svlbox.hxx16
-rw-r--r--svtools/inc/svtools/svtabbx.hxx4
-rw-r--r--svtools/inc/svtools/svtreebx.hxx12
-rw-r--r--svtools/inc/svtools/treelist.hxx24
-rw-r--r--svtools/source/contnr/svimpbox.cxx24
-rw-r--r--svtools/source/contnr/svlbox.cxx42
-rw-r--r--svtools/source/contnr/svtabbx.cxx4
-rw-r--r--svtools/source/contnr/svtreebx.cxx40
-rw-r--r--svtools/source/contnr/treelist.cxx176
-rw-r--r--svtools/source/dialogs/filedlg2.cxx10
-rw-r--r--svtools/source/dialogs/filedlg2.hxx2
-rw-r--r--svtools/source/inc/svimpbox.hxx2
-rw-r--r--svtools/source/uno/treecontrolpeer.cxx8
-rw-r--r--svtools/workben/treecontrol/treetest.cxx6
14 files changed, 185 insertions, 185 deletions
diff --git a/svtools/inc/svtools/svtabbx.hxx b/svtools/inc/svtools/svtabbx.hxx
index aa32ebe019da..749df910edc0 100644
--- a/svtools/inc/svtools/svtabbx.hxx
+++ b/svtools/inc/svtools/svtabbx.hxx
@@ -88,7 +88,7 @@ public:
long GetLogicTab( sal_uInt16 nTab );
virtual SvLBoxEntry* InsertEntry( const XubString& rText, SvLBoxEntry* pParent = 0,
- sal_Bool bChildsOnDemand = sal_False,
+ sal_Bool bChildrenOnDemand = sal_False,
sal_uLong nPos=LIST_APPEND, void* pUserData = 0,
SvLBoxButtonKind eButtonKind = SvLBoxButtonKind_enabledCheckbox );
@@ -96,7 +96,7 @@ public:
const Image& rExpandedEntryBmp,
const Image& rCollapsedEntryBmp,
SvLBoxEntry* pParent = 0,
- sal_Bool bChildsOnDemand = sal_False,
+ sal_Bool bChildrenOnDemand = sal_False,
sal_uLong nPos = LIST_APPEND, void* pUserData = 0,
SvLBoxButtonKind eButtonKind = SvLBoxButtonKind_enabledCheckbox );
diff --git a/svtools/inc/svtools/treelist.hxx b/svtools/inc/svtools/treelist.hxx
index bddb3627a618..a9eff0a6f001 100644
--- a/svtools/inc/svtools/treelist.hxx
+++ b/svtools/inc/svtools/treelist.hxx
@@ -152,7 +152,7 @@ friend class SvListView;
private:
SvListEntry* pParent;
- SvTreeEntryList* pChilds;
+ SvTreeEntryList* pChildren;
sal_uLong nAbsPos;
sal_uLong nListPos;
@@ -166,7 +166,7 @@ public:
SvListEntry();
SvListEntry( const SvListEntry& );
virtual ~SvListEntry();
- sal_Bool HasChilds() { return (sal_Bool)(pChilds!=0); }
+ sal_Bool HasChildren() { return (sal_Bool)(pChildren!=0); }
sal_Bool HasChildListPos() const
{
if( pParent && !(pParent->nListPos & 0x80000000) )
@@ -296,8 +296,8 @@ class SVT_DLLPUBLIC SvTreeList
void Collapse( SvListView*,SvListEntry* pParent );
SVT_DLLPRIVATE void SetAbsolutePositions();
- SVT_DLLPRIVATE SvTreeEntryList*CloneChilds(
- SvTreeEntryList* pChilds,
+ SVT_DLLPRIVATE SvTreeEntryList*CloneChildren(
+ SvTreeEntryList* pChildren,
SvListEntry* pNewParent,
sal_uLong& nCloneCount
) const;
@@ -311,7 +311,7 @@ class SVT_DLLPUBLIC SvTreeList
sal_uLong& rPos
);
- SVT_DLLPRIVATE void ResortChilds( SvListEntry* pParent );
+ SVT_DLLPRIVATE void ResortChildren( SvListEntry* pParent );
protected:
SvListEntry* pRootItem;
@@ -367,7 +367,7 @@ public:
sal_Bool Remove( SvListEntry* pEntry );
void Clear();
- sal_Bool HasChilds( SvListEntry* pEntry ) const;
+ sal_Bool HasChildren( SvListEntry* pEntry ) const;
sal_Bool HasParent( SvListEntry* pEntry ) const
{ return (sal_Bool)(pEntry->pParent!=pRootItem); }
@@ -594,19 +594,19 @@ inline SvViewData* SvListView::GetViewData( SvListEntry* pEntry ) const
#endif
}
-inline sal_Bool SvTreeList::HasChilds( SvListEntry* pEntry ) const
+inline sal_Bool SvTreeList::HasChildren( SvListEntry* pEntry ) const
{
if ( !pEntry )
pEntry = pRootItem;
- return (sal_Bool)(pEntry->pChilds != 0);
+ return (sal_Bool)(pEntry->pChildren != 0);
}
inline SvListEntry* SvTreeList::GetEntry( SvListEntry* pParent, sal_uLong nPos ) const
{ if ( !pParent )
pParent = pRootItem;
SvListEntry* pRet = 0;
- if ( pParent->pChilds )
- pRet = (*pParent->pChilds)[ nPos ];
+ if ( pParent->pChildren )
+ pRet = (*pParent->pChildren)[ nPos ];
return pRet;
}
@@ -614,7 +614,7 @@ inline SvListEntry* SvTreeList::GetEntry( sal_uLong nRootPos ) const
{
SvListEntry* pRet = 0;
if ( nEntryCount )
- pRet = (*pRootItem->pChilds)[ nRootPos ];
+ pRet = (*pRootItem->pChildren)[ nRootPos ];
return pRet;
}
@@ -622,7 +622,7 @@ inline SvTreeEntryList* SvTreeList::GetChildList( SvListEntry* pParent ) const
{
if ( !pParent )
pParent = pRootItem;
- return pParent->pChilds;
+ return pParent->pChildren;
}
inline SvListEntry* SvTreeList::GetParent( SvListEntry* pEntry ) const
diff --git a/svtools/source/contnr/svtabbx.cxx b/svtools/source/contnr/svtabbx.cxx
index 0ee54fee77fd..d9d93092b087 100644
--- a/svtools/source/contnr/svtabbx.cxx
+++ b/svtools/source/contnr/svtabbx.cxx
@@ -182,7 +182,7 @@ void SvTabListBox::SetTab( sal_uInt16 nTab,long nValue,MapUnit eMapUnit )
}
SvLBoxEntry* SvTabListBox::InsertEntry( const XubString& rText, SvLBoxEntry* pParent,
- sal_Bool /*bChildsOnDemand*/,
+ sal_Bool /*bChildrenOnDemand*/,
sal_uLong nPos, void* pUserData,
SvLBoxButtonKind )
{
@@ -193,7 +193,7 @@ SvLBoxEntry* SvTabListBox::InsertEntry( const XubString& rText,
const Image& rExpandedEntryBmp,
const Image& rCollapsedEntryBmp,
SvLBoxEntry* pParent,
- sal_Bool /*bChildsOnDemand*/,
+ sal_Bool /*bChildrenOnDemand*/,
sal_uLong nPos, void* pUserData,
SvLBoxButtonKind )
{
diff --git a/svtools/source/contnr/svtreebx.cxx b/svtools/source/contnr/svtreebx.cxx
index 7820d491e8cd..5fa9bde6b6f2 100644
--- a/svtools/source/contnr/svtreebx.cxx
+++ b/svtools/source/contnr/svtreebx.cxx
@@ -381,7 +381,7 @@ IMPL_LINK_INLINE_END( SvTreeListBox, CheckButtonClick, SvLBoxButtonData *, pData
SvLBoxEntry* SvTreeListBox::InsertEntry(
const XubString& aText,
SvLBoxEntry* pParent,
- sal_Bool bChildsOnDemand, sal_uLong nPos,
+ sal_Bool bChildrenOnDemand, sal_uLong nPos,
void* pUser,
SvLBoxButtonKind eButtonKind
)
@@ -398,7 +398,7 @@ SvLBoxEntry* SvTreeListBox::InsertEntry(
SvLBoxEntry* pEntry = CreateEntry();
pEntry->SetUserData( pUser );
InitEntry( pEntry, aText, rDefColBmp, rDefExpBmp, eButtonKind );
- pEntry->EnableChildsOnDemand( bChildsOnDemand );
+ pEntry->EnableChildrenOnDemand( bChildrenOnDemand );
if( !pParent )
SvLBox::Insert( pEntry, nPos );
@@ -415,7 +415,7 @@ SvLBoxEntry* SvTreeListBox::InsertEntry(
SvLBoxEntry* SvTreeListBox::InsertEntry( const XubString& aText,
const Image& aExpEntryBmp, const Image& aCollEntryBmp,
- SvLBoxEntry* pParent, sal_Bool bChildsOnDemand, sal_uLong nPos, void* pUser,
+ SvLBoxEntry* pParent, sal_Bool bChildrenOnDemand, sal_uLong nPos, void* pUser,
SvLBoxButtonKind eButtonKind )
{
DBG_CHKTHIS(SvTreeListBox,0);
@@ -428,7 +428,7 @@ SvLBoxEntry* SvTreeListBox::InsertEntry( const XubString& aText,
pEntry->SetUserData( pUser );
InitEntry( pEntry, aText, aCollEntryBmp, aExpEntryBmp, eButtonKind );
- pEntry->EnableChildsOnDemand( bChildsOnDemand );
+ pEntry->EnableChildrenOnDemand( bChildrenOnDemand );
if( !pParent )
SvLBox::Insert( pEntry, nPos );
@@ -605,7 +605,7 @@ SvLBoxEntry* SvTreeListBox::CloneEntry( SvLBoxEntry* pSource )
SvLBoxEntry* pClone = CreateEntry();
InitEntry( pClone, aStr, aCollEntryBmp, aExpEntryBmp, eButtonKind );
pClone->SvListEntry::Clone( pSource );
- pClone->EnableChildsOnDemand( pSource->HasChildsOnDemand() );
+ pClone->EnableChildrenOnDemand( pSource->HasChildrenOnDemand() );
pClone->SetUserData( pSource->GetUserData() );
return pClone;
@@ -743,10 +743,10 @@ void SvTreeListBox::KeyInput( const KeyEvent& rKEvt )
nImpFlags &= ~SVLBOX_IS_TRAVELSELECT;
}
-void SvTreeListBox::RequestingChilds( SvLBoxEntry* pParent )
+void SvTreeListBox::RequestingChildren( SvLBoxEntry* pParent )
{
DBG_CHKTHIS(SvTreeListBox,0);
- if( !pParent->HasChilds() )
+ if( !pParent->HasChildren() )
InsertEntry( String::CreateFromAscii("<dummy>"), pParent, sal_False, LIST_APPEND );
}
@@ -938,9 +938,9 @@ sal_Bool SvTreeListBox::Expand( SvLBoxEntry* pParent )
sal_Bool bExpanded = sal_False;
sal_uInt16 nFlags;
- if( pParent->HasChildsOnDemand() )
- RequestingChilds( pParent );
- if( pParent->HasChilds() )
+ if( pParent->HasChildrenOnDemand() )
+ RequestingChildren( pParent );
+ if( pParent->HasChildren() )
{
nImpFlags |= SVLBOX_IS_EXPANDING;
if( ExpandingHdl() )
@@ -1020,12 +1020,12 @@ sal_Bool SvTreeListBox::Select( SvLBoxEntry* pEntry, sal_Bool bSelect )
return bRetVal;
}
-sal_uLong SvTreeListBox::SelectChilds( SvLBoxEntry* pParent, sal_Bool bSelect )
+sal_uLong SvTreeListBox::SelectChildren( SvLBoxEntry* pParent, sal_Bool bSelect )
{
DBG_CHKTHIS(SvTreeListBox,0);
pImp->DestroyAnchor();
sal_uLong nRet = 0;
- if( !pParent->HasChilds() )
+ if( !pParent->HasChildren() )
return 0;
sal_uInt16 nRefDepth = pModel->GetDepth( pParent );
SvLBoxEntry* pChild = FirstChild( pParent );
@@ -1687,7 +1687,7 @@ long SvTreeListBox::PaintEntry1(SvLBoxEntry* pEntry,long nLine,sal_uInt16 nTabFl
if( (!(pEntry->GetFlags() & SV_ENTRYFLAG_NO_NODEBMP)) &&
(nWindowStyle & WB_HASBUTTONS) && pFirstDynamicTab &&
- ( pEntry->HasChilds() || pEntry->HasChildsOnDemand() ) )
+ ( pEntry->HasChildren() || pEntry->HasChildrenOnDemand() ) )
{
// ersten festen Tab suchen, und pruefen ob die Node-Bitmap
// in ihn hineinragt
@@ -1712,7 +1712,7 @@ long SvTreeListBox::PaintEntry1(SvLBoxEntry* pEntry,long nLine,sal_uInt16 nTabFl
pImg = &pImp->GetExpandedNodeBmp( );
else
{
- if( (!pEntry->HasChilds()) && pEntry->HasChildsOnDemand() &&
+ if( (!pEntry->HasChildren()) && pEntry->HasChildrenOnDemand() &&
(!(pEntry->GetFlags() & SV_ENTRYFLAG_HAD_CHILDREN)) &&
pImp->GetDontKnowNodeBmp().GetSizePixel().Width() )
pImg = &pImp->GetDontKnowNodeBmp( );
@@ -1739,8 +1739,8 @@ long SvTreeListBox::PaintEntry1(SvLBoxEntry* pEntry,long nLine,sal_uInt16 nTabFl
aControlValue.setTristateVal( BUTTONVALUE_ON );//expanded node
else
{
- if( (!pEntry->HasChilds() ) &&
- pEntry->HasChildsOnDemand() &&
+ if( (!pEntry->HasChildren() ) &&
+ pEntry->HasChildrenOnDemand() &&
(!(pEntry->GetFlags() & SV_ENTRYFLAG_HAD_CHILDREN)) &&
pImp->GetDontKnowNodeBmp().GetSizePixel().Width()
)
@@ -2125,12 +2125,12 @@ void SvTreeListBox::Command( const CommandEvent& rCEvt )
}
-void SvTreeListBox::RemoveParentKeepChilds( SvLBoxEntry* pParent )
+void SvTreeListBox::RemoveParentKeepChildren( SvLBoxEntry* pParent )
{
DBG_CHKTHIS(SvTreeListBox,0);
- DBG_ASSERT(pParent,"RemoveParentKeepChilds:No Parent");
+ DBG_ASSERT(pParent,"RemoveParentKeepChildren:No Parent");
SvLBoxEntry* pNewParent = GetParent( pParent );
- if( pParent->HasChilds())
+ if( pParent->HasChildren())
{
SvLBoxEntry* pChild = FirstChild( pParent );
while( pChild )
@@ -2444,7 +2444,7 @@ void SvTreeListBox::FillAccessibleEntryStateSet( SvLBoxEntry* pEntry, ::utl::Acc
{
DBG_ASSERT( pEntry, "SvTreeListBox::FillAccessibleEntryStateSet: invalid entry" );
- if ( pEntry->HasChildsOnDemand() || pEntry->HasChilds() )
+ if ( pEntry->HasChildrenOnDemand() || pEntry->HasChildren() )
{
rStateSet.AddState( AccessibleStateType::EXPANDABLE );
if ( IsExpanded( pEntry ) )
diff --git a/svtools/source/contnr/treelist.cxx b/svtools/source/contnr/treelist.cxx
index 4d02022bf913..6b34f512b176 100644
--- a/svtools/source/contnr/treelist.cxx
+++ b/svtools/source/contnr/treelist.cxx
@@ -34,7 +34,7 @@ DBG_NAME(SvListEntry);
SvListEntry::SvListEntry()
{
DBG_CTOR(SvListEntry,0);
- pChilds = 0;
+ pChildren = 0;
pParent = 0;
nListPos = 0;
nAbsPos = 0;
@@ -43,7 +43,7 @@ SvListEntry::SvListEntry()
SvListEntry::SvListEntry( const SvListEntry& rEntry )
{
DBG_CTOR(SvListEntry,0);
- pChilds = 0;
+ pChildren = 0;
pParent = 0;
nListPos &= 0x80000000;
nListPos |= ( rEntry.nListPos & 0x7fffffff);
@@ -53,13 +53,13 @@ SvListEntry::SvListEntry( const SvListEntry& rEntry )
SvListEntry::~SvListEntry()
{
DBG_DTOR(SvListEntry,0);
- if ( pChilds )
+ if ( pChildren )
{
- pChilds->DestroyAll();
- delete pChilds;
+ pChildren->DestroyAll();
+ delete pChildren;
}
#ifdef DBG_UTIL
- pChilds = 0;
+ pChildren = 0;
pParent = 0;
#endif
}
@@ -74,16 +74,16 @@ void SvListEntry::Clone( SvListEntry* pSource)
void SvListEntry::SetListPositions()
{
- if( pChilds )
+ if( pChildren )
{
- SvListEntry *pEntry = (SvListEntry*)pChilds->First();
+ SvListEntry *pEntry = (SvListEntry*)pChildren->First();
sal_uLong nCur = 0;
while ( pEntry )
{
pEntry->nListPos &= 0x80000000;
pEntry->nListPos |= nCur;
nCur++;
- pEntry = (SvListEntry*)pChilds->Next();
+ pEntry = (SvListEntry*)pChildren->Next();
}
}
nListPos &= (~0x80000000);
@@ -252,7 +252,7 @@ sal_uInt16 SvTreeList::GetDepth( SvListEntry* pEntry ) const
void SvTreeList::Clear()
{
Broadcast( LISTACTION_CLEARING );
- SvTreeEntryList* pRootList = pRootItem->pChilds;
+ SvTreeEntryList* pRootList = pRootItem->pChildren;
if ( pRootList )
{
SvListEntry* pEntry = (SvListEntry*)(pRootList->First());
@@ -261,8 +261,8 @@ void SvTreeList::Clear()
delete pEntry;
pEntry = (SvListEntry*)(pRootList->Next());
}
- delete pRootItem->pChilds;
- pRootItem->pChilds = 0;
+ delete pRootItem->pChildren;
+ pRootItem->pChildren = 0;
}
nEntryCount = 0;
Broadcast( LISTACTION_CLEARED );
@@ -281,7 +281,7 @@ sal_Bool SvTreeList::IsChild( SvListEntry* pParent, SvListEntry* pChild ) const
pParent = pRootItem;
sal_Bool bIsChild = sal_False;
- SvTreeEntryList* pList = pParent->pChilds;
+ SvTreeEntryList* pList = pParent->pChildren;
if ( !pList )
return sal_False;
SvListEntry* pActualChild = (SvListEntry*)(pList->First());
@@ -291,7 +291,7 @@ sal_Bool SvTreeList::IsChild( SvListEntry* pParent, SvListEntry* pChild ) const
bIsChild = sal_True;
else
{
- if ( pActualChild->pChilds )
+ if ( pActualChild->pChildren )
bIsChild = IsChild( pActualChild, pChild );
pActualChild = (SvListEntry*)(pList->Next());
}
@@ -309,15 +309,15 @@ sal_uLong SvTreeList::Move(SvListEntry* pSrcEntry,SvListEntry* pTargetParent,sal
Broadcast( LISTACTION_MOVING, pSrcEntry, pTargetParent, nListPos );
- if ( !pTargetParent->pChilds )
- pTargetParent->pChilds = new SvTreeEntryList;
+ if ( !pTargetParent->pChildren )
+ pTargetParent->pChildren = new SvTreeEntryList;
if ( pSrcEntry == pTargetParent )
return pSrcEntry->GetChildListPos();
bAbsPositionsValid = sal_False;
- SvTreeEntryList* pDstList = pTargetParent->pChilds;
- SvTreeEntryList* pSrcList = pSrcEntry->pParent->pChilds;
+ SvTreeEntryList* pDstList = pTargetParent->pChildren;
+ SvTreeEntryList* pSrcList = pSrcEntry->pParent->pChildren;
// Dummy-Ptr einfuegen, weil nListPos durch das
// folgende Remove ungueltig werden koennte
@@ -326,12 +326,12 @@ sal_uLong SvTreeList::Move(SvListEntry* pSrcEntry,SvListEntry* pTargetParent,sal
// loeschen
pSrcList->remove( pSrcEntry );
- // Hat Parent noch Childs ?
+ // Hat Parent noch Children ?
if ( pSrcList->empty() )
{
- // Keine Childs, deshalb Child-List loeschen
+ // Keine Children, deshalb Child-List loeschen
SvListEntry* pParent = pSrcEntry->pParent;
- pParent->pChilds = 0;
+ pParent->pChildren = 0;
delete pSrcList;
pSrcList = 0;
}
@@ -363,8 +363,8 @@ sal_uLong SvTreeList::Copy(SvListEntry* pSrcEntry,SvListEntry* pTargetParent,sal
DBG_ASSERT(pSrcEntry,"Entry?");
if ( !pTargetParent )
pTargetParent = pRootItem;
- if ( !pTargetParent->pChilds )
- pTargetParent->pChilds = new SvTreeEntryList;
+ if ( !pTargetParent->pChildren )
+ pTargetParent->pChildren = new SvTreeEntryList;
bAbsPositionsValid = sal_False;
@@ -372,7 +372,7 @@ sal_uLong SvTreeList::Copy(SvListEntry* pSrcEntry,SvListEntry* pTargetParent,sal
SvListEntry* pClonedEntry = Clone( pSrcEntry, nCloneCount );
nEntryCount += nCloneCount;
- SvTreeEntryList* pDstList = pTargetParent->pChilds;
+ SvTreeEntryList* pDstList = pTargetParent->pChildren;
pClonedEntry->pParent = pTargetParent; // Parent umsetzen
pDstList->insert( pClonedEntry, nListPos ); // Einfuegen
SetListPositions( pDstList ); // Listenpositionen in Zielliste korrigieren
@@ -421,8 +421,8 @@ void SvTreeList::InsertTree(SvListEntry* pSrcEntry,
if ( !pTargetParent )
pTargetParent = pRootItem;
- if ( !pTargetParent->pChilds )
- pTargetParent->pChilds = new SvTreeEntryList;
+ if ( !pTargetParent->pChildren )
+ pTargetParent->pChildren = new SvTreeEntryList;
// Sortierung beruecksichtigen
GetInsertionPos( pSrcEntry, pTargetParent, nListPos );
@@ -430,7 +430,7 @@ void SvTreeList::InsertTree(SvListEntry* pSrcEntry,
bAbsPositionsValid = sal_False;
pSrcEntry->pParent = pTargetParent; // Parent umsetzen
- SvTreeEntryList* pDstList = pTargetParent->pChilds;
+ SvTreeEntryList* pDstList = pTargetParent->pChildren;
pDstList->insert( pSrcEntry, nListPos ); // einfuegen
SetListPositions(pDstList); // Listenpositionen in Zielliste korrigieren
nEntryCount += GetChildCount( pSrcEntry );
@@ -466,9 +466,9 @@ SvListEntry* SvTreeList::Clone( SvListEntry* pEntry, sal_uLong& nCloneCount ) co
{
SvListEntry* pClonedEntry = CloneEntry( pEntry );
nCloneCount = 1;
- SvTreeEntryList* pChilds = pEntry->pChilds;
- if ( pChilds )
- pClonedEntry->pChilds=CloneChilds(pChilds,pClonedEntry,nCloneCount);
+ SvTreeEntryList* pChildren = pEntry->pChildren;
+ if ( pChildren )
+ pClonedEntry->pChildren=CloneChildren(pChildren,pClonedEntry,nCloneCount);
return pClonedEntry;
}
@@ -478,29 +478,29 @@ SvListEntry* SvTreeList::Clone( SvListEntry* pEntry, sal_uLong& nCloneCount ) co
|*
*************************************************************************/
-SvTreeEntryList* SvTreeList::CloneChilds( SvTreeEntryList* pChilds,
+SvTreeEntryList* SvTreeList::CloneChildren( SvTreeEntryList* pChildren,
SvListEntry* pNewParent,
sal_uLong& nCloneCount ) const
{
- DBG_ASSERT(!pChilds->empty(),"Childs?");
- SvTreeEntryList* pClonedChilds = new SvTreeEntryList;
- SvListEntry* pChild = (SvListEntry*)pChilds->First();
+ DBG_ASSERT(!pChildren->empty(),"Children?");
+ SvTreeEntryList* pClonedChildren = new SvTreeEntryList;
+ SvListEntry* pChild = (SvListEntry*)pChildren->First();
while ( pChild )
{
SvListEntry* pNewChild = CloneEntry( pChild );
nCloneCount++;
pNewChild->pParent = pNewParent;
- SvTreeEntryList* pSubChilds = pChild->pChilds;
- if ( pSubChilds )
+ SvTreeEntryList* pSubChildren = pChild->pChildren;
+ if ( pSubChildren )
{
- pSubChilds = CloneChilds( pSubChilds, pNewChild, nCloneCount );
- pNewChild->pChilds = pSubChilds;
+ pSubChildren = CloneChildren( pSubChildren, pNewChild, nCloneCount );
+ pNewChild->pChildren = pSubChildren;
}
- pClonedChilds->push_back( pNewChild );
- pChild = (SvListEntry*)pChilds->Next();
+ pClonedChildren->push_back( pNewChild );
+ pChild = (SvListEntry*)pChildren->Next();
}
- return pClonedChilds;
+ return pClonedChildren;
}
@@ -515,7 +515,7 @@ sal_uLong SvTreeList::GetChildCount( SvListEntry* pParent ) const
if ( !pParent )
return GetEntryCount();
- if ( !pParent || !pParent->pChilds)
+ if ( !pParent || !pParent->pChildren)
return 0;
sal_uLong nCount = 0;
sal_uInt16 nRefDepth = GetDepth( pParent );
@@ -540,7 +540,7 @@ sal_uLong SvTreeList::GetVisibleChildCount(const SvListView* pView, SvListEntry*
DBG_ASSERT(pView,"GetVisChildCount:No View");
if ( !pParent )
pParent = pRootItem;
- if ( !pParent || !pView->IsExpanded(pParent) || !pParent->pChilds )
+ if ( !pParent || !pView->IsExpanded(pParent) || !pParent->pChildren )
return 0;
sal_uLong nCount = 0;
sal_uInt16 nRefDepth = GetDepth( pParent );
@@ -559,7 +559,7 @@ sal_uLong SvTreeList::GetChildSelectionCount(const SvListView* pView,SvListEntry
DBG_ASSERT(pView,"GetChildSelCount:No View");
if ( !pParent )
pParent = pRootItem;
- if ( !pParent || !pParent->pChilds)
+ if ( !pParent || !pParent->pChildren)
return 0;
sal_uLong nCount = 0;
sal_uInt16 nRefDepth = GetDepth( pParent );
@@ -584,7 +584,7 @@ sal_uLong SvTreeList::GetChildSelectionCount(const SvListView* pView,SvListEntry
SvListEntry* SvTreeList::First() const
{
if ( nEntryCount )
- return (SvListEntry*)(*pRootItem->pChilds)[ 0 ];
+ return (SvListEntry*)(*pRootItem->pChildren)[ 0 ];
else
return 0;
}
@@ -608,13 +608,13 @@ SvListEntry* SvTreeList::Next( SvListEntry* pActEntry, sal_uInt16* pDepth ) cons
bWithDepth = sal_True;
}
- SvTreeEntryList* pActualList = pActEntry->pParent->pChilds;
+ SvTreeEntryList* pActualList = pActEntry->pParent->pChildren;
sal_uLong nActualPos = pActEntry->GetChildListPos();
- if ( pActEntry->pChilds /* && pActEntry->pChilds->Count() */ )
+ if ( pActEntry->pChildren /* && pActEntry->pChildren->Count() */ )
{
nDepth++;
- pActEntry = (SvListEntry*)(*pActEntry->pChilds)[ 0 ];
+ pActEntry = (SvListEntry*)(*pActEntry->pChildren)[ 0 ];
if ( bWithDepth )
*pDepth = nDepth;
return pActEntry;
@@ -633,7 +633,7 @@ SvListEntry* SvTreeList::Next( SvListEntry* pActEntry, sal_uInt16* pDepth ) cons
while( pParent != pRootItem && pParent != 0 )
{
DBG_ASSERT(pParent!=0,"TreeData corrupt!");
- pActualList = pParent->pParent->pChilds;
+ pActualList = pParent->pParent->pChildren;
DBG_ASSERT(pActualList,"TreeData corrupt!");
nActualPos = pParent->GetChildListPos();
if ( pActualList->size() > ( nActualPos + 1 ) )
@@ -666,15 +666,15 @@ SvListEntry* SvTreeList::Prev( SvListEntry* pActEntry, sal_uInt16* pDepth ) cons
bWithDepth = sal_True;
}
- SvTreeEntryList* pActualList = pActEntry->pParent->pChilds;
+ SvTreeEntryList* pActualList = pActEntry->pParent->pChildren;
sal_uLong nActualPos = pActEntry->GetChildListPos();
if ( nActualPos > 0 )
{
pActEntry = (SvListEntry*)(*pActualList)[ nActualPos - 1 ];
- while( pActEntry->pChilds )
+ while( pActEntry->pChildren )
{
- pActualList = pActEntry->pChilds;
+ pActualList = pActEntry->pChildren;
nDepth++;
pActEntry = (SvListEntry*)(pActualList->last());
}
@@ -705,14 +705,14 @@ SvListEntry* SvTreeList::Prev( SvListEntry* pActEntry, sal_uInt16* pDepth ) cons
SvListEntry* SvTreeList::Last() const
{
- SvTreeEntryList* pActList = pRootItem->pChilds;
+ SvTreeEntryList* pActList = pRootItem->pChildren;
// if ( pActList->Count() == 0 )
// return 0;
SvListEntry* pEntry = 0;
while( pActList )
{
pEntry = (SvListEntry*)(pActList->last());
- pActList = pEntry->pChilds;
+ pActList = pEntry->pChildren;
// if ( pActList->Count() == 0 )
// pActList = 0;
}
@@ -797,14 +797,14 @@ SvListEntry* SvTreeList::NextVisible(const SvListView* pView,SvListEntry* pActEn
bWithDepth = sal_True;
}
- SvTreeEntryList* pActualList = pActEntry->pParent->pChilds;
+ SvTreeEntryList* pActualList = pActEntry->pParent->pChildren;
sal_uLong nActualPos = pActEntry->GetChildListPos();
if ( pView->IsExpanded(pActEntry) )
{
- DBG_ASSERT(pActEntry->pChilds,"Childs?");
+ DBG_ASSERT(pActEntry->pChildren,"Children?");
nDepth++;
- pActEntry = (SvListEntry*)(*pActEntry->pChilds)[ 0 ];
+ pActEntry = (SvListEntry*)(*pActEntry->pChildren)[ 0 ];
if ( bWithDepth )
*pActDepth = nDepth;
return pActEntry;
@@ -823,7 +823,7 @@ SvListEntry* SvTreeList::NextVisible(const SvListView* pView,SvListEntry* pActEn
nDepth--;
while( pParent != pRootItem )
{
- pActualList = pParent->pParent->pChilds;
+ pActualList = pParent->pParent->pChildren;
nActualPos = pParent->GetChildListPos();
nActualPos++;
if ( pActualList->size() > nActualPos )
@@ -861,7 +861,7 @@ SvListEntry* SvTreeList::PrevVisible(const SvListView* pView, SvListEntry* pActE
bWithDepth = sal_True;
}
- SvTreeEntryList* pActualList = pActEntry->pParent->pChilds;
+ SvTreeEntryList* pActualList = pActEntry->pParent->pChildren;
sal_uLong nActualPos = pActEntry->GetChildListPos();
if ( nActualPos > 0 )
@@ -869,7 +869,7 @@ SvListEntry* SvTreeList::PrevVisible(const SvListView* pView, SvListEntry* pActE
pActEntry = (SvListEntry*)(*pActualList)[ nActualPos - 1 ];
while( pView->IsExpanded(pActEntry) )
{
- pActualList = pActEntry->pChilds;
+ pActualList = pActEntry->pChildren;
nDepth++;
pActEntry = (SvListEntry*)(pActualList->last());
}
@@ -987,8 +987,8 @@ SvListEntry* SvTreeList::FirstChild( SvListEntry* pParent ) const
if ( !pParent )
pParent = pRootItem;
SvListEntry* pResult;
- if ( pParent->pChilds )
- pResult = (SvListEntry*)(*pParent->pChilds)[ 0 ];
+ if ( pParent->pChildren )
+ pResult = (SvListEntry*)(*pParent->pChildren)[ 0 ];
else
pResult = 0;
return pResult;
@@ -999,7 +999,7 @@ SvListEntry* SvTreeList::NextSibling( SvListEntry* pEntry ) const
DBG_ASSERT(pEntry,"Entry?");
if( !pEntry )
return 0;
- SvTreeEntryList* pList = pEntry->pParent->pChilds;
+ SvTreeEntryList* pList = pEntry->pParent->pChildren;
sal_uLong nPos = pEntry->GetChildListPos();
nPos++;
pEntry = (SvListEntry*)(*pList)[ nPos ];
@@ -1012,7 +1012,7 @@ SvListEntry* SvTreeList::PrevSibling( SvListEntry* pEntry ) const
if( !pEntry )
return 0;
- SvTreeEntryList* pList = pEntry->pParent->pChilds;
+ SvTreeEntryList* pList = pEntry->pParent->pChildren;
sal_uLong nPos = pEntry->GetChildListPos();
if ( nPos == 0 )
return 0;
@@ -1028,7 +1028,7 @@ SvListEntry* SvTreeList::LastSibling( SvListEntry* pEntry ) const
if( !pEntry )
return 0;
SvListEntry* pSib = 0;
- SvTreeEntryList* pSibs = pEntry->pParent->pChilds;
+ SvTreeEntryList* pSibs = pEntry->pParent->pChildren;
if ( pSibs )
pSib = (SvListEntry*)(pSibs->last());
return pSib;
@@ -1094,12 +1094,12 @@ sal_uLong SvTreeList::Insert( SvListEntry* pEntry,SvListEntry* pParent,sal_uLong
pParent = pRootItem;
- SvTreeEntryList* pList = pParent->pChilds;
+ SvTreeEntryList* pList = pParent->pChildren;
if ( !pList )
{
// Parent bekommt zum erstenmal ein Kind
pList = new SvTreeEntryList;
- pParent->pChilds = pList;
+ pParent->pChildren = pList;
}
// Sortierung beruecksichtigen
@@ -1170,7 +1170,7 @@ void SvTreeList::Expand( SvListView* pView, SvListEntry* pEntry )
if ( pView->IsExpanded(pEntry) )
return;
- DBG_ASSERT(pEntry->pChilds,"Expand:No Childs!");
+ DBG_ASSERT(pEntry->pChildren,"Expand:No children!");
SvViewData* pViewData = pView->GetViewData(pEntry);
pViewData->nFlags |= SVLISTENTRYFLAG_EXPANDED;
@@ -1198,7 +1198,7 @@ void SvTreeList::Collapse( SvListView* pView, SvListEntry* pEntry )
if ( !pView->IsExpanded(pEntry) )
return;
- DBG_ASSERT(pEntry->pChilds,"Collapse:No Childs!");
+ DBG_ASSERT(pEntry->pChildren,"Collapse:No children!");
SvViewData* pViewData = pView->GetViewData( pEntry );
pViewData->nFlags &=(~SVLISTENTRYFLAG_EXPANDED);
@@ -1275,7 +1275,7 @@ sal_Bool SvTreeList::Remove( SvListEntry* pEntry )
bAbsPositionsValid = sal_False;
SvListEntry* pParent = pEntry->pParent;
- SvTreeEntryList* pList = pParent->pChilds;
+ SvTreeEntryList* pList = pParent->pChildren;
DBG_ASSERT(pList,"Remove:No Childlist");
sal_Bool bLastEntry = sal_False;
@@ -1292,11 +1292,11 @@ sal_Bool SvTreeList::Remove( SvListEntry* pEntry )
// moved to end of method because it is used later with Broadcast
- // delete pEntry; // loescht auch alle Childs
+ // delete pEntry; // loescht auch alle Children
if ( pList->empty() )
{
- pParent->pChilds = 0;
+ pParent->pChildren = 0;
delete pList;
}
else
@@ -1311,7 +1311,7 @@ sal_Bool SvTreeList::Remove( SvListEntry* pEntry )
#endif
Broadcast( LISTACTION_REMOVED, pEntry );
- delete pEntry; // loescht auch alle Childs
+ delete pEntry; // loescht auch alle Children
return sal_True;
}
@@ -1389,8 +1389,8 @@ sal_Bool SvTreeList::IsInChildList( SvListEntry* pParent, SvListEntry* pChild) c
if ( !pParent )
pParent = pRootItem;
sal_Bool bIsChild = sal_False;
- if ( pParent->pChilds )
- bIsChild = (sal_Bool)(pParent->pChilds->GetPos(pChild) != ULONG_MAX);
+ if ( pParent->pChildren )
+ bIsChild = (sal_Bool)(pParent->pChildren->GetPos(pChild) != ULONG_MAX);
return bIsChild;
}
@@ -1600,7 +1600,7 @@ void SvListView::ActionMoving( SvListEntry* pEntry,SvListEntry*,sal_uLong)
DBG_CHKTHIS(SvListView,0);
SvListEntry* pParent = pEntry->pParent;
DBG_ASSERT(pParent,"Model not consistent");
- if( pParent != pModel->pRootItem && pParent->pChilds->size() == 1 )
+ if( pParent != pModel->pRootItem && pParent->pChildren->size() == 1 )
{
SvViewData* pViewData = (SvViewData*)aDataTable.Get( (sal_uLong)pParent );
pViewData->nFlags &= (~SVLISTENTRYFLAG_EXPANDED);
@@ -1645,7 +1645,7 @@ void SvListView::ActionInsertedTree( SvListEntry* pEntry )
nVisibleCount = 0;
bVisPositionsValid = sal_False;
}
- // ueber Entry und seine Childs iterieren
+ // ueber Entry und seine Children iterieren
SvListEntry* pCurEntry = pEntry;
sal_uInt16 nRefDepth = pModel->GetDepth( pCurEntry );
while( pCurEntry )
@@ -1663,18 +1663,18 @@ void SvListView::ActionInsertedTree( SvListEntry* pEntry )
void SvListView::RemoveViewData( SvListEntry* pParent )
{
- SvTreeEntryList* pChilds = pParent->pChilds;
- if( pChilds )
+ SvTreeEntryList* pChildren = pParent->pChildren;
+ if( pChildren )
{
- SvListEntry* pCur = (SvListEntry*)pChilds->First();
+ SvListEntry* pCur = (SvListEntry*)pChildren->First();
while( pCur )
{
SvViewData* pViewData = (SvViewData*)aDataTable.Get((sal_uLong)pCur);
delete pViewData;
aDataTable.Remove( (sal_uLong)pCur );
- if( pCur->HasChilds())
+ if( pCur->HasChildren())
RemoveViewData( pCur );
- pCur = (SvListEntry*)pChilds->Next();
+ pCur = (SvListEntry*)pChildren->Next();
}
}
}
@@ -1713,7 +1713,7 @@ void SvListView::ActionRemoving( SvListEntry* pEntry )
SvListEntry* pCurEntry = pEntry->pParent;
if ( pCurEntry && pCurEntry != pModel->pRootItem &&
- pCurEntry->pChilds->size() == 1 )
+ pCurEntry->pChildren->size() == 1 )
{
pViewData = (SvViewData*)aDataTable.Get((sal_uLong)pCurEntry);
pViewData->nFlags &= (~SVLISTENTRYFLAG_EXPANDED);
@@ -1801,14 +1801,14 @@ void SvTreeList::Resort()
{
Broadcast( LISTACTION_RESORTING );
bAbsPositionsValid = sal_False;
- ResortChilds( pRootItem );
+ ResortChildren( pRootItem );
Broadcast( LISTACTION_RESORTED );
}
-void SvTreeList::ResortChilds( SvListEntry* pParent )
+void SvTreeList::ResortChildren( SvListEntry* pParent )
{
DBG_ASSERT(pParent,"Parent not set");
- SvTreeEntryList* pChildList = pParent->pChilds;
+ SvTreeEntryList* pChildList = pParent->pChildren;
if( !pChildList )
return;
SvTreeEntryList aList( *pChildList );
@@ -1821,8 +1821,8 @@ void SvTreeList::ResortChilds( SvListEntry* pParent )
sal_uLong nListPos = ULONG_MAX;
GetInsertionPos( pCurEntry, pParent, nListPos );
pChildList->insert( pCurEntry, nListPos );
- if( pCurEntry->pChilds )
- ResortChilds( pCurEntry );
+ if( pCurEntry->pChildren )
+ ResortChildren( pCurEntry );
}
SetListPositions( (SvTreeEntryList*)pChildList );
}
diff --git a/svtools/source/dialogs/filedlg2.cxx b/svtools/source/dialogs/filedlg2.cxx
index 6da461b1946b..80ae25ba9298 100644
--- a/svtools/source/dialogs/filedlg2.cxx
+++ b/svtools/source/dialogs/filedlg2.cxx
@@ -258,7 +258,7 @@ void ImpPathDialog::InitControls()
if (pNewDirBtn)
pNewDirBtn->SetClickHdl( LINK( this, ImpPathDialog, ClickHdl) );
- nOwnChilds = pDlg->GetChildCount();
+ nOwnChildren = pDlg->GetChildCount();
}
@@ -560,9 +560,9 @@ void ImpPathDialog::PreExecute()
long nMaxWidth = 0;
// Maximale Breite ermitteln
- sal_uInt16 nChilds = GetPathDialog()->GetChildCount();
+ sal_uInt16 nChildren = GetPathDialog()->GetChildCount();
sal_uInt16 n;
- for ( n = nOwnChilds; n < nChilds; n++ )
+ for ( n = nOwnChildren; n < nChildren; n++ )
{
Window* pChild = GetPathDialog()->GetChild( n );
pChild = pChild->GetWindow( WINDOW_CLIENT );
@@ -593,7 +593,7 @@ void ImpPathDialog::PreExecute()
else
nMaxWidth = aSize.Width();
- for ( n = nOwnChilds; n < nChilds; n++ )
+ for ( n = nOwnChildren; n < nChildren; n++ )
{
Window* pChild = GetPathDialog()->GetChild( n );
pChild = pChild->GetWindow( WINDOW_CLIENT );
@@ -783,7 +783,7 @@ void ImpFileDialog::InitControls()
GetFileDialog()->SetOutputSizePixel( Size(nButtonStartX+STD_BTN_WIDTH+10, 298-nH) );
- nOwnChilds = GetPathDialog()->GetChildCount();
+ nOwnChildren = GetPathDialog()->GetChildCount();
// Handler setzen
if (pDriveList)
diff --git a/svtools/source/dialogs/filedlg2.hxx b/svtools/source/dialogs/filedlg2.hxx
index a7bba2013f55..7492c4b921b3 100644
--- a/svtools/source/dialogs/filedlg2.hxx
+++ b/svtools/source/dialogs/filedlg2.hxx
@@ -91,7 +91,7 @@ private:
PushButton* pHomeBtn;
PushButton* pNewDirBtn;
- sal_uInt16 nOwnChilds;
+ sal_uInt16 nOwnChildren;
DirEntry aPath; // aktuell angewaehlter Pfad
sal_uInt16 nDirCount; // Anzahl der Verzeichnis-
diff --git a/svtools/source/inc/svimpbox.hxx b/svtools/source/inc/svimpbox.hxx
index c52cec54e479..2c3e9d3fae73 100644
--- a/svtools/source/inc/svimpbox.hxx
+++ b/svtools/source/inc/svimpbox.hxx
@@ -240,7 +240,7 @@ private:
void NotifyTabsChanged();
inline sal_Bool IsExpandable() const // if element at cursor can be expanded in general
- { return pCursor->HasChilds() || pCursor->HasChildsOnDemand(); }
+ { return pCursor->HasChildren() || pCursor->HasChildrenOnDemand(); }
inline sal_Bool IsNowExpandable() const // if element at cursor can be expanded at this moment
{ return IsExpandable() && !pView->IsExpanded( pCursor ); }
diff --git a/svtools/source/uno/treecontrolpeer.cxx b/svtools/source/uno/treecontrolpeer.cxx
index eaa08f20e06b..4ab0cbfd5d8d 100644
--- a/svtools/source/uno/treecontrolpeer.cxx
+++ b/svtools/source/uno/treecontrolpeer.cxx
@@ -99,7 +99,7 @@ public:
sal_uInt32 insert( SvLBoxEntry* pEntry,SvLBoxEntry* pParent,sal_uLong nPos=LIST_APPEND );
- virtual void RequestingChilds( SvLBoxEntry* pParent );
+ virtual void RequestingChildren( SvLBoxEntry* pParent );
virtual sal_Bool EditingEntry( SvLBoxEntry* pEntry, Selection& );
virtual sal_Bool EditedEntry( SvLBoxEntry* pEntry, const XubString& rNewText );
@@ -317,9 +317,9 @@ bool TreeControlPeer::updateEntry( UnoTreeListEntry* pEntry )
}
}
- if( (pEntry->mxNode->hasChildrenOnDemand() == sal_True) != (pEntry->HasChildsOnDemand() == sal_True) )
+ if( (pEntry->mxNode->hasChildrenOnDemand() == sal_True) != (pEntry->HasChildrenOnDemand() == sal_True) )
{
- pEntry->EnableChildsOnDemand( pEntry->mxNode->hasChildrenOnDemand() ? sal_True : sal_False );
+ pEntry->EnableChildrenOnDemand( pEntry->mxNode->hasChildrenOnDemand() ? sal_True : sal_False );
bChanged = true;
}
@@ -1582,7 +1582,7 @@ sal_uInt32 UnoTreeListBoxImpl::insert( SvLBoxEntry* pEntry,SvLBoxEntry* pParent,
// --------------------------------------------------------------------
-void UnoTreeListBoxImpl::RequestingChilds( SvLBoxEntry* pParent )
+void UnoTreeListBoxImpl::RequestingChildren( SvLBoxEntry* pParent )
{
UnoTreeListEntry* pEntry = dynamic_cast< UnoTreeListEntry* >( pParent );
if( pEntry && pEntry->mxNode.is() && mxPeer.is() )
diff --git a/svtools/workben/treecontrol/treetest.cxx b/svtools/workben/treecontrol/treetest.cxx
index 7209159c9ca5..419094f2252d 100644
--- a/svtools/workben/treecontrol/treetest.cxx
+++ b/svtools/workben/treecontrol/treetest.cxx
@@ -245,13 +245,13 @@ void DirectoryTree::fillNode( const Reference< XMutableTreeNode >& xNode )
// XTreeExpansionListener
void SAL_CALL DirectoryTree::requestChildNodes( const TreeExpansionEvent& rEvent ) throw (RuntimeException)
{
- if( rEvent.Node.is() && rEvent.Node->hasChildsOnDemand() )
+ if( rEvent.Node.is() && rEvent.Node->hasChildrenOnDemand() )
{
Reference< XMutableTreeNode > xNode( rEvent.Node, UNO_QUERY );
if( xNode.is() )
{
fillNode( xNode );
- xNode->setHasChildsOnDemand( sal_False );
+ xNode->setHasChildrenOnDemand( sal_False );
}
}
}
@@ -278,7 +278,7 @@ void SAL_CALL DirectoryTree::treeCollapsed( const TreeExpansionEvent& /*rEvent*/
{
while( xNode->getChildCount() )
xNode->removeChildByIndex(0);
- xNode->setHasChildsOnDemand( sal_True );
+ xNode->setHasChildrenOnDemand( sal_True );
}
}
*/
diff --git a/svtools/inc/svtools/svlbox.hxx b/svtools/inc/svtools/svlbox.hxx
index 414ff7786bdb..b246854e6a13 100644
--- a/svtools/inc/svtools/svlbox.hxx
+++ b/svtools/inc/svtools/svlbox.hxx
@@ -172,10 +172,10 @@ public:
};
// Flags, die am Model haengen
-#define SV_ENTRYFLAG_CHILDS_ON_DEMAND 0x0001
+#define SV_ENTRYFLAG_CHILDREN_ON_DEMAND 0x0001
#define SV_ENTRYFLAG_DISABLE_DROP 0x0002
#define SV_ENTRYFLAG_IN_USE 0x0004
// wird gesetzt, wenn RequestingChilds keine Childs gestzt hat
#define SV_ENTRYFLAG_NO_NODEBMP 0x0008
// Eintrag hatte oder hat Kinder
#define SV_ENTRYFLAG_HAD_CHILDREN 0x0010
@@ -208,8 +208,8 @@ public:
void* GetUserData() const { return pUserData; }
void SetUserData( void* pPtr ) { pUserData = pPtr; }
virtual void Clone( SvListEntry* pSource );
- void EnableChildsOnDemand( sal_Bool bEnable=sal_True );
- sal_Bool HasChildsOnDemand() const { return (sal_Bool)((nEntryFlags & SV_ENTRYFLAG_CHILDS_ON_DEMAND)!=0); }
+ void EnableChildrenOnDemand( sal_Bool bEnable=sal_True );
+ sal_Bool HasChildrenOnDemand() const { return (sal_Bool)((nEntryFlags & SV_ENTRYFLAG_CHILDREN_ON_DEMAND)!=0); }
sal_Bool HasInUseEmphasis() const { return (sal_Bool)((nEntryFlags & SV_ENTRYFLAG_IN_USE)!=0); }
sal_uInt16 GetFlags() const { return nEntryFlags; }
@@ -307,7 +307,7 @@ protected:
sal_Bool CheckDragAndDropMode( SvLBox* pSource, sal_Int8 );
void ImplShowTargetEmphasis( SvLBoxEntry* pEntry, sal_Bool bShow);
void EnableSelectionAsDropTarget( sal_Bool bEnable = sal_True,
- sal_Bool bWithChilds = sal_True );
+ sal_Bool bWithChildren = sal_True );
// standard impl gibt 0 zurueck; muss von abgeleiteten Klassen, die
// D&D unterstuetzen, ueberladen werden
using Window::GetDropTarget;
@@ -481,7 +481,7 @@ public:
virtual sal_Bool Expand( SvLBoxEntry* pParent );
virtual sal_Bool Collapse( SvLBoxEntry* pParent );
virtual sal_Bool Select( SvLBoxEntry* pEntry, sal_Bool bSelect=sal_True );
- virtual sal_uLong SelectChilds( SvLBoxEntry* pParent, sal_Bool bSelect );
+ virtual sal_uLong SelectChildren( SvLBoxEntry* pParent, sal_Bool bSelect );
virtual void SelectAll( sal_Bool bSelect, sal_Bool bPaint=sal_True );
virtual void SetCurEntry( SvLBoxEntry* _pEntry ) = 0;
@@ -508,8 +508,8 @@ public:
SvLBoxItem* GetHdlItem() const;
// wird aufgerufen, wenn ein Eintrag mit gesetztem
- // ENTRYFLAG_CHILDS_ON_DEMAND expandiert wird.
- virtual void RequestingChilds( SvLBoxEntry* pParent );
+ // ENTRYFLAG_CHILDREN_ON_DEMAND expandiert wird.
+ virtual void RequestingChildren( SvLBoxEntry* pParent );
// Drag & Drop
@@ -172,10 +172,10 @@ public:
#define SV_ENTRYFLAG_DISABLE_DROP 0x0002
#define SV_ENTRYFLAG_IN_USE 0x0004
-// wird gesetzt, wenn RequestingChilds keine Childs gestzt hat
+// wird gesetzt, wenn RequestingChildren keine Children gestzt hat
#define SV_ENTRYFLAG_NO_NODEBMP 0x0008
// Eintrag hatte oder hat Kinder
diff --git a/svtools/inc/svtools/svtreebx.hxx b/svtools/inc/svtools/svtreebx.hxx
index b46ebe73f6b5..eab00e7c4368 100644
--- a/svtools/inc/svtools/svtreebx.hxx
+++ b/svtools/inc/svtools/svtreebx.hxx
@@ -202,7 +202,7 @@ public:
}
virtual SvLBoxEntry* InsertEntry( const XubString& rText, SvLBoxEntry* pParent = 0,
- sal_Bool bChildsOnDemand = sal_False,
+ sal_Bool bChildrenOnDemand = sal_False,
sal_uLong nPos=LIST_APPEND, void* pUserData = 0,
SvLBoxButtonKind eButtonKind = SvLBoxButtonKind_enabledCheckbox );
@@ -210,7 +210,7 @@ public:
const Image& rExpandedEntryBmp,
const Image& rCollapsedEntryBmp,
SvLBoxEntry* pParent = 0,
- sal_Bool bChildsOnDemand = sal_False,
+ sal_Bool bChildrenOnDemand = sal_False,
sal_uLong nPos = LIST_APPEND, void* pUserData = 0,
SvLBoxButtonKind eButtonKind = SvLBoxButtonKind_enabledCheckbox );
@@ -256,7 +256,7 @@ public:
void EndEditing( sal_Bool bCancel = sal_False ) { SvLBox::EndEditing( bCancel ); }
sal_Bool EditingCanceled() const { return SvLBox::EditingCanceled(); }
- virtual void RequestingChilds( SvLBoxEntry* pParent );
+ virtual void RequestingChildren( SvLBoxEntry* pParent );
virtual void Paint( const Rectangle& rRect );
virtual void MouseButtonDown( const MouseEvent& rMEvt );
@@ -326,7 +326,7 @@ public:
virtual sal_Bool Expand( SvLBoxEntry* pParent );
virtual sal_Bool Collapse( SvLBoxEntry* pParent );
virtual sal_Bool Select( SvLBoxEntry* pEntry, sal_Bool bSelect=sal_True );
- virtual sal_uLong SelectChilds( SvLBoxEntry* pParent, sal_Bool bSelect );
+ virtual sal_uLong SelectChildren( SvLBoxEntry* pParent, sal_Bool bSelect );
virtual void SelectAll( sal_Bool bSelect, sal_Bool bPaint = sal_True );
virtual void SetCurEntry( SvLBoxEntry* _pEntry );
virtual SvLBoxEntry*
@@ -340,8 +340,8 @@ public:
virtual Region GetDragRegion() const;
- // Childs des Parents werden Childs des naechstoberen Parents
- void RemoveParentKeepChilds( SvLBoxEntry* pParent );
+ // Children des Parents werden Children des naechstoberen Parents
+ void RemoveParentKeepChildren( SvLBoxEntry* pParent );
DECL_LINK( DefaultCompare, SvSortData* );
virtual void ModelNotification( sal_uInt16 nActionId, SvListEntry* pEntry1,
diff --git a/svtools/source/contnr/svimpbox.cxx b/svtools/source/contnr/svimpbox.cxx
index 603730f6a14b..7f6665bc1c2f 100644
--- a/svtools/source/contnr/svimpbox.cxx
+++ b/svtools/source/contnr/svimpbox.cxx
@@ -197,7 +197,7 @@ void SvImpLBox::UpdateContextBmpWidthVectorFromMovedEntry( SvLBoxEntry* pEntry )
short nMax = Max(nExpWidth, nColWidth);
UpdateContextBmpWidthVector( pEntry, nMax );
- if( pEntry->HasChilds() ) // recursive call, whether expanded or not
+ if( pEntry->HasChildren() ) // recursive call, whether expanded or not
{
SvLBoxEntry* pChild = pView->FirstChild( pEntry );
DBG_ASSERT( pChild, "The first child is invalid!" );
@@ -996,7 +996,7 @@ void SvImpLBox::MakeVisible( SvLBoxEntry* pEntry, sal_Bool bMoveToTop )
}
pParent = pView->GetParent( pParent );
}
// Passen Childs der Parents in View oder muessen wir scrollen ?
if( IsEntryInView( pEntry ) && !bMoveToTop )
return; // Scrollen nicht noetig -> tschuess
}
@@ -1041,8 +1041,8 @@ void SvImpLBox::ScrollToAbsPos( long nPos )
void SvImpLBox::DrawNet()
{
- if( pView->GetVisibleCount() < 2 && !pStartEntry->HasChildsOnDemand() &&
- !pStartEntry->HasChilds() )
+ if( pView->GetVisibleCount() < 2 && !pStartEntry->HasChildrenOnDemand() &&
+ !pStartEntry->HasChildren() )
return;
//for platforms who don't have nets, DrawNativeControl does nothing and return true
@@ -1713,7 +1713,7 @@ void SvImpLBox::RemovingEntry( SvLBoxEntry* pEntry )
}
if( pEntry == pMostRightEntry || (
- pEntry->HasChilds() && pView->IsExpanded(pEntry) &&
+ pEntry->HasChildren() && pView->IsExpanded(pEntry) &&
pTree->IsChild(pEntry, pMostRightEntry)))
{
nFlags |= F_REMOVED_RECALC_MOST_RIGHT;
@@ -1741,7 +1741,7 @@ void SvImpLBox::RemovingEntry( SvLBoxEntry* pEntry )
if( bSimpleTravel )
pView->Select( pCursor, sal_False );
ShowCursor( sal_False ); // Focus-Rect weg
// NextSibling, weil auch Childs des Cursors geloescht werden
pTemp = pView->NextSibling( pCursor );
if( !pTemp )
pTemp = (SvLBoxEntry*)(pView->PrevVisible( pCursor ));
@@ -1832,7 +1832,7 @@ void SvImpLBox::MovingEntry( SvLBoxEntry* pEntry )
if( pEntry == pStartEntry )
{
SvLBoxEntry* pNew = 0;
- if( !pEntry->HasChilds() )
+ if( !pEntry->HasChildren() )
{
pNew = (SvLBoxEntry*)(pView->NextVisible( pStartEntry ));
if( !pNew )
@@ -2051,7 +2051,7 @@ sal_Bool SvImpLBox::ButtonUpCheckCtrl( const MouseEvent& rMEvt )
// sal_False == kein Expand/Collapse-Button getroffen
sal_Bool SvImpLBox::IsNodeButton( const Point& rPosPixel, SvLBoxEntry* pEntry ) const
{
- if( !pEntry->HasChilds() && !pEntry->HasChildsOnDemand() )
+ if( !pEntry->HasChildren() && !pEntry->HasChildrenOnDemand() )
return sal_False;
SvLBoxTab* pFirstDynamicTab = pView->GetFirstDynamicTab();
@@ -2160,7 +2160,7 @@ void SvImpLBox::MouseButtonDown( const MouseEvent& rMEvt )
return;
}
- if( pEntry->HasChilds() || pEntry->HasChildsOnDemand() )
+ if( pEntry->HasChildren() || pEntry->HasChildrenOnDemand() )
{
if( pView->IsExpanded(pEntry) )
pView->Collapse( pEntry );
@@ -2513,7 +2513,7 @@ sal_Bool SvImpLBox::KeyInput( const KeyEvent& rKEvt)
SvLBoxEntry* pCur = pTree->Next( pCursor );
while( pCur && pTree->GetDepth(pCur) > nRefDepth )
{
- if( pCur->HasChilds() && !pView->IsExpanded(pCur))
+ if( pCur->HasChildren() && !pView->IsExpanded(pCur))
pView->Expand( pCur );
pCur = pTree->Next( pCur );
}
@@ -2563,7 +2563,7 @@ sal_Bool SvImpLBox::KeyInput( const KeyEvent& rKEvt)
SvLBoxEntry* pCur = pTree->Next( pParentToCollapse );
while( pCur && pTree->GetDepth(pCur) > nRefDepth )
{
- if( pCur->HasChilds() && pView->IsExpanded(pCur) )
+ if( pCur->HasChildren() && pView->IsExpanded(pCur) )
pView->Collapse( pCur );
pCur = pTree->Next( pCur );
}
@@ -3439,7 +3439,7 @@ void SvImpLBox::FindMostRight_Impl( SvLBoxEntry* pParent, SvLBoxEntry* pEntryToI
if( pChild != pEntryToIgnore )
{
SetMostRight( pChild );
- if( pChild->HasChilds() && pView->IsExpanded( pChild ))
+ if( pChild->HasChildren() && pView->IsExpanded( pChild ))
FindMostRight_Impl( pChild, pEntryToIgnore );
}
}
@@ -996,7 +996,7 @@ void SvImpLBox::MakeVisible( SvLBoxEntry* pEntry, sal_Bool bMoveToTop )
pParent = pView->GetParent( pParent );
}
- // Passen Childs der Parents in View oder muessen wir scrollen ?
+ // Passen Children der Parents in View oder muessen wir scrollen ?
if( IsEntryInView( pEntry ) && !bMoveToTop )
return; // Scrollen nicht noetig -> tschuess
@@ -1741,7 +1741,7 @@ void SvImpLBox::RemovingEntry( SvLBoxEntry* pEntry )
pView->Select( pCursor, sal_False );
ShowCursor( sal_False ); // Focus-Rect weg
- // NextSibling, weil auch Childs des Cursors geloescht werden
+ // NextSibling, weil auch Children des Cursors geloescht werden
pTemp = pView->NextSibling( pCursor );
if( !pTemp )
diff --git a/svtools/source/contnr/svlbox.cxx b/svtools/source/contnr/svlbox.cxx
index f5cd0d2d6f1c..623b5fbebadf 100644
--- a/svtools/source/contnr/svlbox.cxx
+++ b/svtools/source/contnr/svlbox.cxx
@@ -617,13 +617,13 @@ void SvLBoxEntry::Clone( SvListEntry* pSource )
nEntryFlags = ((SvLBoxEntry*)pSource)->nEntryFlags;
}
-void SvLBoxEntry::EnableChildsOnDemand( sal_Bool bEnable )
+void SvLBoxEntry::EnableChildrenOnDemand( sal_Bool bEnable )
{
DBG_CHKTHIS(SvLBoxEntry,0);
if ( bEnable )
- nEntryFlags |= SV_ENTRYFLAG_CHILDS_ON_DEMAND;
+ nEntryFlags |= SV_ENTRYFLAG_CHILDREN_ON_DEMAND;
else
- nEntryFlags &= (~SV_ENTRYFLAG_CHILDS_ON_DEMAND);
+ nEntryFlags &= (~SV_ENTRYFLAG_CHILDREN_ON_DEMAND);
}
void SvLBoxEntry::ReplaceItem( SvLBoxItem* pNewItem, sal_uInt16 nPos )
@@ -907,7 +907,7 @@ void SvLBox::NotifyRemoving( SvLBoxEntry* )
Standard-Verhalten:
- 1. Target hat keine Childs
+ 1. Target hat keine Children
- Entry wird Sibling des Targets. Entry steht hinter dem
Target (->Fenster: Unter dem Target)
2. Target ist ein aufgeklappter Parent
@@ -939,7 +939,7 @@ sal_Bool SvLBox::NotifyMoving(
rNewChildPos = 0;
return sal_True;
}
- if ( !pTarget->HasChilds() && !pTarget->HasChildsOnDemand() )
+ if ( !pTarget->HasChildren() && !pTarget->HasChildrenOnDemand() )
{
// Fall 1
rpNewParent = GetParent( pTarget );
@@ -976,7 +976,7 @@ sal_Bool SvLBox::NotifyCopying(
rNewChildPos = 0;
return sal_True;
}
- if ( !pTarget->HasChilds() && !pTarget->HasChildsOnDemand() )
+ if ( !pTarget->HasChildren() && !pTarget->HasChildrenOnDemand() )
{
// Fall 1
rpNewParent = GetParent( pTarget );
@@ -1021,8 +1021,8 @@ sal_Bool SvLBox::CopySelection( SvLBox* pSource, SvLBoxEntry* pTarget )
SvLBoxEntry* pSourceEntry = pSource->FirstSelected();
while ( pSourceEntry )
{
- // Childs werden automatisch mitkopiert
- pSource->SelectChilds( pSourceEntry, sal_False );
+ // Children werden automatisch mitkopiert
+ pSource->SelectChildren( pSourceEntry, sal_False );
aList.push_back( pSourceEntry );
pSourceEntry = pSource->NextSelected( pSourceEntry );
}
@@ -1082,8 +1082,8 @@ sal_Bool SvLBox::MoveSelectionCopyFallbackPossible( SvLBox* pSource, SvLBoxEntry
SvLBoxEntry* pSourceEntry = pSource->FirstSelected();
while ( pSourceEntry )
{
- // Childs werden automatisch mitbewegt
- pSource->SelectChilds( pSourceEntry, sal_False );
+ // Children werden automatisch mitbewegt
+ pSource->SelectChildren( pSourceEntry, sal_False );
aList.push_back( pSourceEntry );
pSourceEntry = pSource->NextSelected( pSourceEntry );
}
@@ -1143,9 +1143,9 @@ void SvLBox::RemoveSelection()
while ( pEntry )
{
aList.push_back( pEntry );
- if ( pEntry->HasChilds() )
- // Remove loescht Childs automatisch
- SelectChilds( pEntry, sal_False );
+ if ( pEntry->HasChildren() )
+ // Remove loescht Children automatisch
+ SelectChildren( pEntry, sal_False );
pEntry = NextSelected( pEntry );
}
pEntry = (SvLBoxEntry*)aList.First();
@@ -1161,7 +1161,7 @@ SvLBox* SvLBox::GetSourceView() const
return pDDSource;
}
-void SvLBox::RequestingChilds( SvLBoxEntry* )
+void SvLBox::RequestingChildren( SvLBoxEntry* )
{
DBG_CHKTHIS(SvLBox,0);
OSL_FAIL("Child-Request-Hdl not implemented!");
@@ -1236,7 +1236,7 @@ sal_Bool SvLBox::Select( SvLBoxEntry*, sal_Bool )
return sal_False;
}
-sal_uLong SvLBox::SelectChilds( SvLBoxEntry* , sal_Bool )
+sal_uLong SvLBox::SelectChildren( SvLBoxEntry* , sal_Bool )
{
DBG_CHKTHIS(SvLBox,0);
return 0;
@@ -1365,7 +1365,7 @@ void SvLBox::InitViewData( SvViewData* pData, SvListEntry* pEntry )
-void SvLBox::EnableSelectionAsDropTarget( sal_Bool bEnable, sal_Bool bWithChilds )
+void SvLBox::EnableSelectionAsDropTarget( sal_Bool bEnable, sal_Bool bWithChildren )
{
DBG_CHKTHIS(SvLBox,0);
sal_uInt16 nRefDepth;
@@ -1377,7 +1377,7 @@ void SvLBox::EnableSelectionAsDropTarget( sal_Bool bEnable, sal_Bool bWithChilds
if ( !bEnable )
{
pSelEntry->nEntryFlags |= SV_ENTRYFLAG_DISABLE_DROP;
- if ( bWithChilds )
+ if ( bWithChildren )
{
nRefDepth = pModel->GetDepth( pSelEntry );
pTemp = Next( pSelEntry );
@@ -1391,7 +1391,7 @@ void SvLBox::EnableSelectionAsDropTarget( sal_Bool bEnable, sal_Bool bWithChilds
else
{
pSelEntry->nEntryFlags &= (~SV_ENTRYFLAG_DISABLE_DROP);
- if ( bWithChilds )
+ if ( bWithChildren )
{
nRefDepth = pModel->GetDepth( pSelEntry );
pTemp = Next( pSelEntry );
@@ -1555,7 +1555,7 @@ const void* SvLBox::NextSearchEntry( const void* _pCurrentSearchEntry, String& _
SvLBoxEntry* pEntry = const_cast< SvLBoxEntry* >( static_cast< const SvLBoxEntry* >( _pCurrentSearchEntry ) );
if ( ( ( GetChildCount( pEntry ) > 0 )
- || ( pEntry->HasChildsOnDemand() )
+ || ( pEntry->HasChildrenOnDemand() )
)
&& !IsExpanded( pEntry )
)
@@ -1824,12 +1824,12 @@ void SvLBox::StartDrag( sal_Int8, const Point& rPosPixel )
Update();
Control::SetUpdateMode( bOldUpdateMode );
// Selektion & deren Childs im Model als DropTargets sperren
// Wichtig: Wenn im DropHandler die Selektion der
// SourceListBox veraendert wird, muessen vorher die Eintraege
// als DropTargets wieder freigeschaltet werden:
// (GetSourceListBox()->EnableSelectionAsDropTarget( sal_True, sal_True );)
- EnableSelectionAsDropTarget( sal_False, sal_True /* with Childs */ );
+ EnableSelectionAsDropTarget( sal_False, sal_True /* with children */ );
pContainer->StartDrag( this, nDragOptions, GetDragFinishedHdl() );
}
@@ -1824,12 +1824,12 @@ void SvLBox::StartDrag( sal_Int8, const Point& rPosPixel )
Update();
Control::SetUpdateMode( bOldUpdateMode );
- // Selektion & deren Childs im Model als DropTargets sperren
+ // Selektion & deren Children im Model als DropTargets sperren
// Wichtig: Wenn im DropHandler die Selektion der
// SourceListBox veraendert wird, muessen vorher die Eintraege